==> jc-1.4.0.tar.gz: java/text/RuleBasedCollator__24CollationElement.h <==
// final class java.text.RuleBasedCollator$CollationElement

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5c80afc8f9e85945 java_text_RuleBasedCollator__24CollationElement

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_text_RuleBasedCollator__24CollationElement_H_
#define _JC_java_text_RuleBasedCollator__24CollationElement_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_text_RuleBasedCollator__24CollationElement$sub_refs	_jc_java_text_RuleBasedCollator__24CollationElement$sub_refs;
typedef struct _jc_java_text_RuleBasedCollator__24CollationElement$sub_nonrefs	_jc_java_text_RuleBasedCollator__24CollationElement$sub_nonrefs;
typedef struct _jc_java_text_RuleBasedCollator__24CollationElement$refs	_jc_java_text_RuleBasedCollator__24CollationElement$refs;
typedef struct _jc_java_text_RuleBasedCollator__24CollationElement$nonrefs	_jc_java_text_RuleBasedCollator__24CollationElement$nonrefs;
typedef struct _jc_java_text_RuleBasedCollator__24CollationElement$object	_jc_java_text_RuleBasedCollator__24CollationElement$object;

typedef const struct _jc_java_text_RuleBasedCollator__24CollationElement$vmethods	_jc_java_text_RuleBasedCollator__24CollationElement$vmethods;
typedef const struct _jc_java_text_RuleBasedCollator__24CollationElement$vtable	_jc_java_text_RuleBasedCollator__24CollationElement$vtable;
typedef const struct _jc_java_text_RuleBasedCollator__24CollationElement$vtype	_jc_java_text_RuleBasedCollator__24CollationElement$vtype;

// Constructors
extern void _jc_java_text_RuleBasedCollator__24CollationElement$method$_init$cb447f39a17cefa0(_jc_env *, struct _jc_java_text_RuleBasedCollator__24CollationElement$object *, struct _jc_java_lang_String$object *, jint, jshort, jshort, jshort, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods
extern jint _jc_java_text_RuleBasedCollator__24CollationElement$method$getValue$245714dca3f59de3(_jc_env *, struct _jc_java_text_RuleBasedCollator__24CollationElement$object *);

// Virtual method descriptors
extern _jc_method _jc_java_text_RuleBasedCollator__24CollationElement$method_info$getValue$245714dca3f59de3;

// Virtual methods structure
struct _jc_java_text_RuleBasedCollator__24CollationElement$vmethods {
	jint	(*getValue$245714dca3f59de3)(_jc_env *, struct _jc_java_text_RuleBasedCollator__24CollationElement$object *);
};

// Vtable
struct _jc_java_text_RuleBasedCollator__24CollationElement$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_text_RuleBasedCollator__24CollationElement$vmethods	java_text_RuleBasedCollator__24CollationElement;
};

// Vtype
struct _jc_java_text_RuleBasedCollator__24CollationElement$vtype {
	_jc_type			type;
	_jc_java_text_RuleBasedCollator__24CollationElement$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_text_RuleBasedCollator__24CollationElement$sub_refs {
	struct _jc_java_lang_String$object	*key;
	struct _jc_java_lang_String$object	*expansion;
};

// Reference instance fields (object)
struct _jc_java_text_RuleBasedCollator__24CollationElement$refs {
    _jc_java_text_RuleBasedCollator__24CollationElement$sub_refs	java_text_RuleBasedCollator__24CollationElement;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_text_RuleBasedCollator__24CollationElement$sub_nonrefs {
	jint	primary;
	jshort	secondary;
	jshort	tertiary;
	jshort	equality;
	jboolean	ignore;
};

// Non-reference instance fields (object)
struct _jc_java_text_RuleBasedCollator__24CollationElement$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_text_RuleBasedCollator__24CollationElement$sub_nonrefs	java_text_RuleBasedCollator__24CollationElement;
};

// Object instance structure
struct _jc_java_text_RuleBasedCollator__24CollationElement$object {
	_jc_java_text_RuleBasedCollator__24CollationElement$refs	refs[0];
	_jc_word		lockword;
	_jc_java_text_RuleBasedCollator__24CollationElement$vtype	*vtype;
	_jc_java_text_RuleBasedCollator__24CollationElement$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_text_RuleBasedCollator__24CollationElement$vtype _jc_java_text_RuleBasedCollator__24CollationElement$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_text_RuleBasedCollator__24CollationElement, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_text_RuleBasedCollator__24CollationElement$class_object;

#endif	/* _JC_java_text_RuleBasedCollator__24CollationElement_H_ */

==> jc-1.4.6.tar.gz: java/text/RuleBasedCollator__24CollationElement.h <==
// final class java.text.RuleBasedCollator$CollationElement

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5c80afc8f9e85945 java_text_RuleBasedCollator__24CollationElement

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_text_RuleBasedCollator__24CollationElement_H_
#define _JC_java_text_RuleBasedCollator__24CollationElement_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_text_RuleBasedCollator__24CollationElement$sub_refs	_jc_java_text_RuleBasedCollator__24CollationElement$sub_refs;
typedef struct _jc_java_text_RuleBasedCollator__24CollationElement$sub_nonrefs	_jc_java_text_RuleBasedCollator__24CollationElement$sub_nonrefs;
typedef struct _jc_java_text_RuleBasedCollator__24CollationElement$refs	_jc_java_text_RuleBasedCollator__24CollationElement$refs;
typedef struct _jc_java_text_RuleBasedCollator__24CollationElement$nonrefs	_jc_java_text_RuleBasedCollator__24CollationElement$nonrefs;
typedef struct _jc_java_text_RuleBasedCollator__24CollationElement$object	_jc_java_text_RuleBasedCollator__24CollationElement$object;

typedef const struct _jc_java_text_RuleBasedCollator__24CollationElement$vmethods	_jc_java_text_RuleBasedCollator__24CollationElement$vmethods;
typedef const struct _jc_java_text_RuleBasedCollator__24CollationElement$vtable	_jc_java_text_RuleBasedCollator__24CollationElement$vtable;
typedef const struct _jc_java_text_RuleBasedCollator__24CollationElement$vtype	_jc_java_text_RuleBasedCollator__24CollationElement$vtype;

// Constructors
extern void _jc_java_text_RuleBasedCollator__24CollationElement$method$_init$cb447f39a17cefa0(_jc_env *, struct _jc_java_text_RuleBasedCollator__24CollationElement$object *, struct _jc_java_lang_String$object *, jint, jshort, jshort, jshort, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_java_text_RuleBasedCollator__24CollationElement$method$getValue$245714dca3f59de3(_jc_env *, struct _jc_java_text_RuleBasedCollator__24CollationElement$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_text_RuleBasedCollator__24CollationElement$method_info$getValue$245714dca3f59de3;

// Virtual methods structure
struct _jc_java_text_RuleBasedCollator__24CollationElement$vmethods {
	jint	(*getValue$245714dca3f59de3)(_jc_env *, struct _jc_java_text_RuleBasedCollator__24CollationElement$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_text_RuleBasedCollator__24CollationElement$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_text_RuleBasedCollator__24CollationElement$vmethods	java_text_RuleBasedCollator__24CollationElement;
};

// Vtype
struct _jc_java_text_RuleBasedCollator__24CollationElement$vtype {
	_jc_type			type;
	_jc_java_text_RuleBasedCollator__24CollationElement$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_text_RuleBasedCollator__24CollationElement$sub_refs {
	struct _jc_java_lang_String$object	*key;
	struct _jc_java_lang_String$object	*expansion;
};

// Reference instance fields (object)
struct _jc_java_text_RuleBasedCollator__24CollationElement$refs {
    _jc_java_text_RuleBasedCollator__24CollationElement$sub_refs	java_text_RuleBasedCollator__24CollationElement;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_text_RuleBasedCollator__24CollationElement$sub_nonrefs {
	jint	primary;
	jshort	secondary;
	jshort	tertiary;
	jshort	equality;
	jboolean	ignore;
};

// Non-reference instance fields (object)
struct _jc_java_text_RuleBasedCollator__24CollationElement$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_text_RuleBasedCollator__24CollationElement$sub_nonrefs	java_text_RuleBasedCollator__24CollationElement;
};

// Object instance structure
struct _jc_java_text_RuleBasedCollator__24CollationElement$object {
	_jc_java_text_RuleBasedCollator__24CollationElement$refs	refs[0];
	_jc_word		lockword;
	_jc_java_text_RuleBasedCollator__24CollationElement$vtype	*vtype;
	_jc_java_text_RuleBasedCollator__24CollationElement$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_text_RuleBasedCollator__24CollationElement$vtype _jc_java_text_RuleBasedCollator__24CollationElement$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_text_RuleBasedCollator__24CollationElement, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_text_RuleBasedCollator__24CollationElement$class_object;

#endif	/* _JC_java_text_RuleBasedCollator__24CollationElement_H_ */
